
import { createRoot } from 'react-dom/client';
import App from './App.tsx';
import './index.css';

// Register Service Worker
if ('serviceWorker' in navigator) {
  window.addEventListener('load', async () => {
    try {
      // Unregister any existing service workers first
      const registrations = await navigator.serviceWorker.getRegistrations();
      for (let registration of registrations) {
        await registration.unregister();
      }

      // Register the new service worker
      const registration = await navigator.serviceWorker.register('/sw.js', {
        scope: '/'
      });
      console.log('Service Worker registration successful:', registration);
      
      // Check if service worker is active
      if (registration.active) {
        console.log('Service Worker is active');
      } else {
        console.log('Service Worker is not yet active');
        // Wait for the service worker to become active
        registration.addEventListener('activate', () => {
          console.log('Service Worker is now active');
        });
      }
    } catch (error) {
      console.error('Service Worker registration failed:', error);
    }
  });
}

createRoot(document.getElementById("root")!).render(<App />);

